package chemicraft;

import java.util.ArrayList;
import java.util.HashMap;

import net.minecraft.src.Block;
import net.minecraft.src.GuiContainer;
import net.minecraft.src.InventoryBasic;
import net.minecraft.src.InventoryPlayer;
import net.minecraft.src.ItemStack;
import cpw.mods.fml.common.Side;
import cpw.mods.fml.common.asm.SideOnly;
import cpw.mods.fml.common.network.PacketDispatcher;

@SideOnly(Side.CLIENT)
public class GuiScienceCraftingTable extends GuiContainer {

	/**
	 * 分解機GUIのInventoryBasicクラス
	 */
	private static InventoryBasic decompositionSlots = new InventoryBasic("Decomposition", 17);


	/**
	 * TabListのArrayList
	 */
	private ArrayList<ChemiCraftTab> tabList = new ArrayList<ChemiCraftTab>();


	/**
	 * Gui画像のHashMap
	 * キーの名前は拡張子を除くファイル名にする
	 */
	private HashMap<String, Integer> guiImageMap = new HashMap<String, Integer>();


	/**
	 * 画像のHashMap
	 * キーの名前は拡張子を除くファイル名にする
	 */
	private HashMap<String, Integer> otherImageMap = new HashMap<String, Integer>();



	/**
	 * the TileEntity.
	 */
	private TileEntityScienceCraftingTable tileEntity;



	public GuiScienceCraftingTable(InventoryPlayer par1InventoryPlayer, TileEntityScienceCraftingTable par2){
		super(new ContainerScienceCraftingTable(par1InventoryPlayer, par2));
		//TileEntityを設定
		this.tileEntity = par2;
		//TabListにTabを追加する
		this.addTabs(0, "Decomposition", new ItemStack(Block.tnt.blockID, 1, 1));
		this.addTabs(1, "Test", new ItemStack(Block.bedrock.blockID, 1, 1));
		//ActiveTabの初期化
		for(int i = 0;i < tabList.size();i++){
			String field_00001 = this.tabList.get(i).getTabName();
			String field_00002 = this.tileEntity.getActiveTab();
			if(field_00001.equals(field_00002)){
				this.tileEntity.setActiveTab(this.tabList.get(i).getTabName());
			}
		}
	}



	@Override
	protected void mouseClicked(int par1, int par2, int par3){
		super.mouseClicked(par1, par2, par3);

		int var1 = par1 - this.guiLeft;
		int var2 = par2 - this.guiTop;
		if(var1 < this.tabList.size() * 28 && var1 >= 0 && var2 < 0){
			String var3 = this.tabList.get(var1 / 28).getTabName();
			if(!var3.equals(this.tileEntity.getActiveTab())){
				this.tileEntity.setActiveTab(var3);
			}
		}
	}



	@Override
	protected void drawGuiContainerBackgroundLayer(float par1, int par2, int par3){
		//ActiveTab Reset.
		this.func_00003();
		//Texture Load.
		this.func_00002();
		//Draw Tabs.
		this.func_00001(par1, par2, par3);
		//Draw GUI
		if(this.tileEntity.getActiveTab().equals("Decomposition")){
			this.mc.renderEngine.bindTexture(this.guiImageMap.get("Decomposition"));
			this.drawTexturedModalRect(this.guiLeft, this.guiTop, 0, 0, this.xSize, this.ySize);
		}
		//TileEntity of ActiveTab Reset.
		this.tileEntity.setActiveTab(this.tileEntity.getActiveTab());
	}



	private void func_00001(float par1, int par2, int par3){
		int var1 = this.guiLeft;
		int var2 = this.guiTop - 32;
		for(int i = 0;i < this.tabList.size();i++){
			if(!this.tabList.get(i).isActive()){
				this.mc.renderEngine.bindTexture(this.otherImageMap.get("tabs"));
				this.drawTexturedModalRect(var1 + (28 * i), var2, 0, 0, 28, 32);
				this.itemRenderer.renderItemIntoGUI(this.fontRenderer, this.mc.renderEngine, this.tabList.get(i).getRenderItemStack(), var1 + (28 * i) + 6, var2 + 9);
				this.itemRenderer.renderItemOverlayIntoGUI(this.fontRenderer, this.mc.renderEngine, this.tabList.get(i).getRenderItemStack(), var1 + (28 * i) + 6, var2 + 9);
			}else{
				this.mc.renderEngine.bindTexture(this.otherImageMap.get("tabs"));
				this.drawTexturedModalRect(var1 + (28 * i), var2, 0, 32, 28, 32);
				this.itemRenderer.renderItemIntoGUI(this.fontRenderer, this.mc.renderEngine, this.tabList.get(i).getRenderItemStack(), var1 + (28 * i) + 6, var2 + 9);
				this.itemRenderer.renderItemOverlayIntoGUI(this.fontRenderer, this.mc.renderEngine, this.tabList.get(i).getRenderItemStack(), var1 + (28 * i) + 6, var2 + 9);
			}
		}
	}



	private void func_00002(){
		//guiImageMapに画像を格納する
		guiImageMap.put("Decomposition", this.mc.renderEngine.getTexture("/ChemiCraft/guis/Decomposition.png"));
		//otherImageMapに画像を格納する
		otherImageMap.put("tabs", this.mc.renderEngine.getTexture("/ChemiCraft/guis/tabs.png"));
	}



	private void func_00003(){
		for(int i = 0;i < this.tabList.size();i++){
			if(!this.tabList.get(i).getTabName().equals(this.tileEntity.getActiveTab())){
				this.tabList.get(i).setActive(false);
			}else{
				this.tabList.get(i).setActive(true);
			}
		}
	}



	/**
	 * ChemiCraftTabを追加します。
	 * @param id TabのID
	 * @param texture OverlayするTextureID
	 * @param name Tabの名前
	 * @throws Exception IDが重複している場合にスローされます
	 */
	private void addTabs(int id, String name, ItemStack renderItemStack){
		for(int i = 0;i < this.tabList.size();i++){
			if(id == this.tabList.get(i).getID()){
				try {
					throw new Exception("ChemiCraft内でエラー:ChemiCraftTabのIDが重複しています");
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}
		this.tabList.add(new ChemiCraftTab(id, name, renderItemStack));
	}

}
